<?php
/*
Plugin Name: Image Rotator
Description: A simple plugin to rotate hyperlinked images with an admin panel and shortcode.
Version: 1.3
Author: SB
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Enqueue necessary scripts and styles
function ir_enqueue_scripts() {
    wp_enqueue_script('jquery');
    wp_enqueue_script('ir-rotator', plugin_dir_url(__FILE__) . 'js/rotator.js', array('jquery'), null, true);
    wp_enqueue_style('ir-rotator-style', plugin_dir_url(__FILE__) . 'css/rotator.css');
    
    // Localize script to pass PHP variables to JavaScript
    $rotation_time = get_option('ir_rotation_time', 3000); // Default to 3000ms if not set
    $transition_duration = get_option('ir_transition_duration', 1000); // Default to 1000ms if not set
    wp_localize_script('ir-rotator', 'ir_vars', array(
        'rotation_time' => $rotation_time,
        'transition_duration' => $transition_duration
    ));
}
add_action('wp_enqueue_scripts', 'ir_enqueue_scripts');

// Admin menu and settings
function ir_register_menu() {
    add_menu_page('Image Rotator', 'Image Rotator', 'manage_options', 'image-rotator', 'ir_settings_page', 'dashicons-images-alt2');
}
add_action('admin_menu', 'ir_register_menu');

function ir_settings_page() {
    ?>
    <div class="wrap">
        <h1>Image Rotator Settings</h1>
        <p>Use this page to add images that you want to rotate on your site. Enter each image with its link on a new line in the format: <code>URL|Link</code>. For example:</p>
        <pre>https://example.com/image1.jpg|https://example.com/page1</pre>
        <pre>https://example.com/image2.jpg|https://example.com/page2</pre>
        <p>Once you've added your images, use the shortcode <code>[image_rotator]</code> in any post or page to display the rotating images.</p>
		<p>*Now you can set the speed of the rotation and the duration below, also please style the div to match your website in the rotator.css file.</p>
        <form method="post" action="options.php">
            <?php
            settings_fields('ir_settings_group');
            do_settings_sections('image-rotator');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

function ir_register_settings() {
    register_setting('ir_settings_group', 'ir_images');
    register_setting('ir_settings_group', 'ir_rotation_time'); // Register the rotation time setting
    register_setting('ir_settings_group', 'ir_transition_duration'); // Register the transition duration setting
    
    add_settings_section('ir_main_section', 'Main Settings', null, 'image-rotator');
    
    add_settings_field('ir_images_field', 'Images', 'ir_images_field_callback', 'image-rotator', 'ir_main_section');
    add_settings_field('ir_rotation_time_field', 'Rotation Time (ms)', 'ir_rotation_time_field_callback', 'image-rotator', 'ir_main_section'); // Add the rotation time field
    add_settings_field('ir_transition_duration_field', 'Transition Duration (ms)', 'ir_transition_duration_field_callback', 'image-rotator', 'ir_main_section'); // Add the transition duration field
}
add_action('admin_init', 'ir_register_settings');

function ir_images_field_callback() {
    $images = get_option('ir_images');
    ?>
    <textarea name="ir_images" rows="10" cols="50" class="large-text"><?php echo esc_textarea($images); ?></textarea>
    <p>Enter images in the following format: <code>URL|Link</code> (one per line).</p>
    <?php
}

function ir_rotation_time_field_callback() {
    $rotation_time = get_option('ir_rotation_time', 3000); // Default to 3000ms if not set
    ?>
    <input type="number" name="ir_rotation_time" value="<?php echo esc_attr($rotation_time); ?>" />
    <p>Enter the rotation time in milliseconds.</p>
    <p>Lower the number the faster it will rotate!</p>
    <?php
}

function ir_transition_duration_field_callback() {
    $transition_duration = get_option('ir_transition_duration', 1000); // Default to 1000ms if not set
    ?>
    <input type="number" name="ir_transition_duration" value="<?php echo esc_attr($transition_duration); ?>" />
    <p>Enter the transition duration in milliseconds.</p>
	<p>Lower the number the faster it will rotate!</p>
    <?php
}

// Shortcode to display rotating images
function ir_rotator_shortcode() {
    $images = get_option('ir_images');
    if (!$images) return '';
    
    $images = explode("\n", $images);
    $output = '<div class="ir-rotator">';
    
    foreach ($images as $image) {
        list($url, $link) = explode('|', $image);
        $output .= '<div class="ir-rotator-item"><a href="' . esc_url($link) . '"><img src="' . esc_url($url) . '" /></a></div>';
    }
    
    $output .= '</div>';
    
    return $output;
}
add_shortcode('image_rotator', 'ir_rotator_shortcode');
?>
